<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="he">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>יש ללחוץ על הסמל שבמגש
או ללחוץ שוב על קיצור המקשים בשביל להפסיק את ההסרטה</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>אל תסובבו 화면 במהלך הקלטה</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>צילום מסך</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>הקלטה</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>הקלטה</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>צילום מסך</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>צילום מסך</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>צילום המסך נכשל. נא לשמור אותו בתיקיית הבית</translation>
    </message>
    <message>
        <source>View</source>
        <translation>הצגה</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>צילום המסך נכשל</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>בחר שטח</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>שמירה</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>נשמר בתור %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>התעלם</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>לוח גיבוי</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>האחסון של קובץ הקלטה של המסך, אנא המתן...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>כשהטיפוס על החלון אופס, עליך להפסיק את ההקלטה</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>צילום מסך</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>הצילום מסך נכשל.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>צינורטשאט</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>העתקת תמונות מסך</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>פתח תיקייה</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>צילום מסך הושלם והעתק ללוח גיבוי</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>בטל</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>שמירה</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>יציאה</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>העתקת תמונות מסך</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>צילום מסך</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>הקלטה</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>צילום מסך</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>הקלטה</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>ההסרטה הסתיימה</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>נשמר ל-%1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>הקלטה</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>פתח תיקייה</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>הapture של המסך יתחיל תוך %1 שניות</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>קבל עזרה.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>נכשל בלקיחת צילום מסך רציף.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>הגעת לתחתית האזור שיכור</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>הגעת לאורך המаксימלי</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>שנה את האזור לapture</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>שנה את גלגל העכבר או לחץ כדי לקח צילום מסך שיכור</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>האט את מהירות השיכור</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>אזור לא חוקי, לחץ כדי </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>הכנס טקסט כאן</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>시작/צילום מסך</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>יציאה/הוספת</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>تعديل גודל</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>התחלה מהירה</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>צילום מסך של החלון</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>השהה צילום מסך</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>צילום מסך מלא</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>יציאה</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>שמור</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>مستطيل</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>אליפסה</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>เส้น</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>עפרון</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>טקסט</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>בטל</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>הגדל את הגובה מעלה</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>הגדל את הגובה למטה</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>הגדל את הרוחב לשמאל</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>הגדל רוחב ימין</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>הקטין גובה למעלה</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>הקטין גובה למטה</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>הקטין רוחב שמאל</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>הקטין רוחב ימין</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>עזרה</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>הצגת קיצורי מפתח</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>צלילים</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>מפתח</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>כובע צילום</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>התחלה בהסרטה</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>אפשרויות</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>הפעלה/녹ום</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>עכבר</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>أدوات</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>הוצא טקסט</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>스크ראשוט</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>תמונה מוצלפת</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>הפעל OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>הפעל סקרראשוט</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>חץ</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>תמונה מוצלפת</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>녹ום</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>مستطيل
לחץ ושמור על Shift כדי לצייר ריבוע</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>אליפסה
לחץ ושמור על Shift כדי לצייר עיגול</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>עיפרון
לחץ ושמור על Shift כדי לצייר קוו ישר</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>התאם עוצמת בור (החליק כדי להתאים)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>התאם גודל עיפרון (החליק כדי להתאים)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>התאם גודל טקסט (החליק כדי להתאים)</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation>יש ללחוץ או לגרור
כדי לבחור את האזור להסרטה</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>הצגת מפתח (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>החבת מפתח (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>הצגת לחיצה (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>ativar a câmera (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>desativar a câmera (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de tela</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Configurações (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sound</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Microphone</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Áudio do sistema</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>אפשרויו</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Mostrar ponteiro</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Mostrar clique</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Salvar para</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation>Reactangle (R)
לחץ וחזיק ב-Shift כדי לצייר ריבוע</translation>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation>אליפסה (O)
לחץ וחזיק ב-Shift כדי לצייר עיגול</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>קו (L)
לחץ וחזיק ב-Shift כדי לצייר קו אנכי או אופקי</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>סימן מ矢 (X)
לחץ וחזיק ב-Shift כדי לצייר סימן מ矢 אנכי או אופקי</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>עיפרון (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>הטיהור (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>טקסט (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>צפתור (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>הסרת טקסט (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>חיבוש צלילים (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>לבטל (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>לצפות</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>לוח</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>תמונות</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>תיקייה</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>הגדר מסלול נשמר</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>לשנות את המסלול בעת שמירה</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>פורמט</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>تأثيرים של גבול</translation>
    </message>
    <message>
        <source>None</source>
        <translation>ללא</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>צלם</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>גבול</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>장치</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>הסרת טקסט</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>סגור (Esc)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>בסדר (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>התאמת האזור של ה録制 בתוך %1*%2 כדי לקבל תأثير וידאו טוב יותר</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>ה録制 של מסך אינו נתמך ברגע זה</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>יציאה</translation>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation>録制 חדשה</translation>
    </message>
</context>
</TS>
